package com.huimv.eartag2.manage2.service.impl;

import com.huimv.eartag2.common.utils.Result;
import com.huimv.eartag2.common.utils.ResultCode;
import com.huimv.eartag2.manage2.pojo.BasePigpen;
import com.huimv.eartag2.manage2.mapper.BasePigpenMapper;
import com.huimv.eartag2.manage2.service.BasePigpenService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.huimv.eartag2.manage2.utils.IDUtil;
import com.huimv.eartag2.manage2.utils.ResultUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * <p>
 *  服务实现类
 * </p>
 *
 * @author zn
 * @since 2022-07-22
 */
@Service
public class BasePigpenServiceImpl extends ServiceImpl<BasePigpenMapper, BasePigpen> implements BasePigpenService {
    @Autowired
    private BasePigpenMapper basePigpenMapper;
    @Autowired
    private ResultUtil resultUtil;
    @Autowired
    private IDUtil idUtil;

    /**
     * @Method      : addBuilding
     * @Description :
     * @Params      : [farmCode, buildingName, buildingCode, stageCode, sort, type]
     * @Return      : com.huimv.eartag2.common.utils.Result
     * 
     * @Author      : ZhuoNing
     * @Date        : 2022/7/23       
     * @Time        : 15:16
     */
    @Override
    public Result addBuilding(String farmCode, String buildingName, String buildingCode, String stageCode, Integer sort, Integer type) {
        BasePigpen newBasePigpen = new BasePigpen();
        newBasePigpen.setFarmCode(farmCode);
        newBasePigpen.setPigpenCode(buildingCode);
        newBasePigpen.setPigpenName(buildingName);
        newBasePigpen.setStageCode(stageCode);
        newBasePigpen.setSort(sort);
        newBasePigpen.setType(type);
        return resultUtil.result(basePigpenMapper.insert(newBasePigpen));
    }

    @Override
    public Result editBuilding(String id, String buildingName, String buildingCode, String stageCode, Integer sort, Integer type) {
        BasePigpen basePigpen = basePigpenMapper.selectById(id);
        if(basePigpen == null){
            return new Result(ResultCode.FAIL,"该记录不存在.");
        }else{
            basePigpen.setPigpenName(buildingName);
            basePigpen.setStageCode(stageCode);
            basePigpen.setSort(sort);
            return resultUtil.result(basePigpenMapper.updateById(basePigpen));
        }
    }

    @Override
    public Result remove(String ids) {
        return resultUtil.result(basePigpenMapper.deleteBatchIds(idUtil.convert(ids)));
    }

    @Override
    public Result addUnit(String farmCode, String parentId, String unitName, String unitCode, String stageCode, Integer sort, Integer type) {
        BasePigpen newBasePigpen = new BasePigpen();
        newBasePigpen.setFarmCode(farmCode);
        newBasePigpen.setPigpenCode(unitCode);
        newBasePigpen.setPigpenName(unitName);
        newBasePigpen.setParentId(Integer.parseInt(parentId));
        newBasePigpen.setSort(sort);
        newBasePigpen.setType(type);
        newBasePigpen.setStageCode(stageCode);
        return resultUtil.result(basePigpenMapper.insert(newBasePigpen));
    }

    @Override
    public Result editUnit(String id, String parentId, String unitName, String unitCode, String stageCode, Integer sort, Integer type) {
        BasePigpen basePigpen = basePigpenMapper.selectById(id);
        if(basePigpen == null){
            return new Result(ResultCode.FAIL,"该记录不存在.");
        }else{
            basePigpen.setPigpenCode(unitCode);
            basePigpen.setPigpenName(unitName);
            basePigpen.setParentId(Integer.parseInt(parentId));
            basePigpen.setSort(sort);
            basePigpen.setType(type);
            basePigpen.setStageCode(stageCode);
            return resultUtil.result(basePigpenMapper.updateById(basePigpen));
        }
    }
}
